package main

import (
	"fmt"
	"sort"
	"strings"
)

type logs []string

func buildChangelog(pageMap map[string]*requirement) (error, string, bool) {

	changelog := make(map[string]logs)
	datemap := make(map[string]string)

	for _, q := range pageMap {
		p := *q

		id := p.ID
		if id != "" {
			id = " (" + strings.TrimSpace(id) + ")"
		}

		title := strings.Trim(p.Title, " ")
		if title == "" {
			title = printer.Sprintf("Untitled")
		}

		e := title + id

		d := p.Created.String()
		datemap[d] = p.Created.Format(config.Locale.DateFormat)
		if p.Created.Before(p.LastUpdate) {
			d = p.LastUpdate.String()
			datemap[d] = p.LastUpdate.Format(config.Locale.DateFormat)
		}

		changelog[d] = append(changelog[d], e)

	}

	hasChangelog := false
	result := ""

	var sortedKeys sort.StringSlice
	for k := range changelog {
		sortedKeys = append(sortedKeys, k)
	}

	sort.Sort(sort.Reverse(sortedKeys))

	for _, k := range sortedKeys {

		result += "### " + datemap[k] + "\n\n"

		for _, m := range changelog[k] {
			result += "- " + m + "\n"
		}

		result += "\n"
		hasChangelog = true

	}

	return nil, result, hasChangelog

}

func printChangelog() error {

	err, pageData := collectStructureFromFiles(config.Path)
	if err != nil {
		return err
	}

	err, table, _ := buildChangelog(pageData)
	fmt.Println(table)
	return err
}
